Crate void_audit_tui

Crate void_audit_tui 

void-audit-tui: Interactive TUI for auditing void repository objects.

This crate provides a terminal user interface for exploring and auditing all objects in a void repository, including commits, metadata bundles, and shards.

Modules

app
Main application for void-audit-tui.
color
Color theming for the audit TUI.
event
Event handling for the audit TUI.
keybind
Keybinding system for the audit TUI.
void_backend
Void repository backend for audit TUI.
widget
TUI widgets for the audit interface.